==> jc-1.4.0.tar.gz: gnu/java/security/provider/MD5withRSA.h <==
// public class gnu.java.security.provider.MD5withRSA

// class file dependencies
// @dep_class ac7f6bda7ca59119 gnu_java_security_provider_MD5withRSA
// @dep_class 63f588e99f359fd2 gnu_java_security_provider_RSA
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 15e444274ebb7a6e java_security_SignatureSpi

// header file dependencies
// @dep_header gnu_java_security_provider_RSA

#include "gnu/java/security/provider/RSA.h"

#ifndef _JC_gnu_java_security_provider_MD5withRSA_H_
#define _JC_gnu_java_security_provider_MD5withRSA_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_MD5withRSA$sub_refs	_jc_gnu_java_security_provider_MD5withRSA$sub_refs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs	_jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$refs	_jc_gnu_java_security_provider_MD5withRSA$refs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$nonrefs	_jc_gnu_java_security_provider_MD5withRSA$nonrefs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$object	_jc_gnu_java_security_provider_MD5withRSA$object;

typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vmethods	_jc_gnu_java_security_provider_MD5withRSA$vmethods;
typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vtable	_jc_gnu_java_security_provider_MD5withRSA$vtable;
typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vtype	_jc_gnu_java_security_provider_MD5withRSA$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_MD5withRSA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_MD5withRSA$object *);

// Virtual methods structure
struct _jc_gnu_java_security_provider_MD5withRSA$vmethods {
};

// Vtable
struct _jc_gnu_java_security_provider_MD5withRSA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SignatureSpi$vmethods	java_security_SignatureSpi;
	_jc_gnu_java_security_provider_RSA$vmethods	gnu_java_security_provider_RSA;
	_jc_gnu_java_security_provider_MD5withRSA$vmethods	gnu_java_security_provider_MD5withRSA;
};

// Vtype
struct _jc_gnu_java_security_provider_MD5withRSA$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_MD5withRSA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_MD5withRSA$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_MD5withRSA$refs {
    _jc_gnu_java_security_provider_MD5withRSA$sub_refs	gnu_java_security_provider_MD5withRSA;
    _jc_gnu_java_security_provider_RSA$sub_refs	gnu_java_security_provider_RSA;
    _jc_java_security_SignatureSpi$sub_refs	java_security_SignatureSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_MD5withRSA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SignatureSpi$sub_nonrefs	java_security_SignatureSpi;
    _jc_gnu_java_security_provider_RSA$sub_nonrefs	gnu_java_security_provider_RSA;
    _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs	gnu_java_security_provider_MD5withRSA;
};

// Object instance structure
struct _jc_gnu_java_security_provider_MD5withRSA$object {
	_jc_gnu_java_security_provider_MD5withRSA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_MD5withRSA$vtype	*vtype;
	_jc_gnu_java_security_provider_MD5withRSA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_MD5withRSA$vtype _jc_gnu_java_security_provider_MD5withRSA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_MD5withRSA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_MD5withRSA$class_object;

#endif	/* _JC_gnu_java_security_provider_MD5withRSA_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/MD5withRSA.h <==
// public class gnu.java.security.provider.MD5withRSA

// class file dependencies
// @dep_class ac7f6bda7ca59119 gnu_java_security_provider_MD5withRSA
// @dep_class bb8c94f5abddd613 gnu_java_security_provider_RSA
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 15e444274ebb7a6e java_security_SignatureSpi

// header file dependencies
// @dep_header gnu_java_security_provider_RSA

#include "gnu/java/security/provider/RSA.h"

#ifndef _JC_gnu_java_security_provider_MD5withRSA_H_
#define _JC_gnu_java_security_provider_MD5withRSA_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_MD5withRSA$sub_refs	_jc_gnu_java_security_provider_MD5withRSA$sub_refs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs	_jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$refs	_jc_gnu_java_security_provider_MD5withRSA$refs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$nonrefs	_jc_gnu_java_security_provider_MD5withRSA$nonrefs;
typedef struct _jc_gnu_java_security_provider_MD5withRSA$object	_jc_gnu_java_security_provider_MD5withRSA$object;

typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vmethods	_jc_gnu_java_security_provider_MD5withRSA$vmethods;
typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vtable	_jc_gnu_java_security_provider_MD5withRSA$vtable;
typedef const struct _jc_gnu_java_security_provider_MD5withRSA$vtype	_jc_gnu_java_security_provider_MD5withRSA$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_MD5withRSA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_MD5withRSA$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_MD5withRSA$vmethods {
};

// Vtable
struct _jc_gnu_java_security_provider_MD5withRSA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_SignatureSpi$vmethods	java_security_SignatureSpi;
	_jc_gnu_java_security_provider_RSA$vmethods	gnu_java_security_provider_RSA;
	_jc_gnu_java_security_provider_MD5withRSA$vmethods	gnu_java_security_provider_MD5withRSA;
};

// Vtype
struct _jc_gnu_java_security_provider_MD5withRSA$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_MD5withRSA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_MD5withRSA$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_MD5withRSA$refs {
    _jc_gnu_java_security_provider_MD5withRSA$sub_refs	gnu_java_security_provider_MD5withRSA;
    _jc_gnu_java_security_provider_RSA$sub_refs	gnu_java_security_provider_RSA;
    _jc_java_security_SignatureSpi$sub_refs	java_security_SignatureSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_MD5withRSA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_SignatureSpi$sub_nonrefs	java_security_SignatureSpi;
    _jc_gnu_java_security_provider_RSA$sub_nonrefs	gnu_java_security_provider_RSA;
    _jc_gnu_java_security_provider_MD5withRSA$sub_nonrefs	gnu_java_security_provider_MD5withRSA;
};

// Object instance structure
struct _jc_gnu_java_security_provider_MD5withRSA$object {
	_jc_gnu_java_security_provider_MD5withRSA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_MD5withRSA$vtype	*vtype;
	_jc_gnu_java_security_provider_MD5withRSA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_MD5withRSA$vtype _jc_gnu_java_security_provider_MD5withRSA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_MD5withRSA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_MD5withRSA$class_object;

#endif	/* _JC_gnu_java_security_provider_MD5withRSA_H_ */
